==> apache-ignite-2.8.1-src.zip: apache-ignite-2.8.1-src/modules/platforms/dotnet/Apache.Ignite.Core/Configuration/ThinClientConfiguration.cs <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

namespace Apache.Ignite.Core.Configuration
{
    using System.ComponentModel;

    /// <summary>
    /// Server-side thin client specific configuration.
    /// </summary>
    public class ThinClientConfiguration
    {
        /// <summary>
        /// Default limit of active transactions count per connection.
        /// </summary>
        public const int DefaultMaxActiveTxPerConnection = 100;

        /// <summary>
        /// Initializes a new instance of the <see cref="ThinClientConfiguration"/> class.
        /// </summary>
        public ThinClientConfiguration()
        {
            MaxActiveTxPerConnection = DefaultMaxActiveTxPerConnection;
        }

        /// <summary>
        /// Gets or sets active transactions count per connection limit.
        /// </summary>
        [DefaultValue(DefaultMaxActiveTxPerConnection)]
        public int MaxActiveTxPerConnection { get; set; }
    }
}

==> apache-ignite-2.12.0-src.zip: apache-ignite-2.12.0-src/modules/platforms/dotnet/Apache.Ignite.Core/Configuration/ThinClientConfiguration.cs <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

namespace Apache.Ignite.Core.Configuration
{
    using System.ComponentModel;

    /// <summary>
    /// Server-side thin client specific configuration.
    /// </summary>
    public class ThinClientConfiguration
    {
        /// <summary>
        /// Default limit of active transactions count per connection.
        /// </summary>
        public const int DefaultMaxActiveTxPerConnection = 100;

        /// <summary>
        /// Default limit of active compute tasks per connection.
        /// </summary>
        public const int DefaultMaxActiveComputeTasksPerConnection = 0;

        /// <summary>
        /// Initializes a new instance of the <see cref="ThinClientConfiguration"/> class.
        /// </summary>
        public ThinClientConfiguration()
        {
            MaxActiveTxPerConnection = DefaultMaxActiveTxPerConnection;
            MaxActiveComputeTasksPerConnection = DefaultMaxActiveComputeTasksPerConnection;
        }

        /// <summary>
        /// Gets or sets active transactions count per connection limit.
        /// </summary>
        [DefaultValue(DefaultMaxActiveTxPerConnection)]
        public int MaxActiveTxPerConnection { get; set; }

        /// <summary>
        /// Gets or sets active compute tasks per connection limit.
        /// Value <c>0</c> means that compute grid functionality is disabled for thin clients.
        /// </summary>
        [DefaultValue(DefaultMaxActiveComputeTasksPerConnection)]
        public int MaxActiveComputeTasksPerConnection { get; set; }
    }
}
